### R code from vignette source 'PanelExercise1.Rnw'
### Encoding: UTF-8

###################################################
### code chunk number 1: Load (eval = FALSE)
###################################################
## install.packages("plm")


###################################################
### code chunk number 2: Call
###################################################
## Load plm package
library(plm)


###################################################
### code chunk number 3: Help (eval = FALSE)
###################################################
## ?plm


###################################################
### code chunk number 4: Vignette (eval = FALSE)
###################################################
## vignette("plm")


###################################################
### code chunk number 5: LoadData
###################################################
data <- read.csv(file="jtrain.csv",h=TRUE,na.strings=".")


###################################################
### code chunk number 6: pdata
###################################################
pdata <- pdata.frame(data,index=c("Fcode","Year"))


###################################################
### code chunk number 7: pdata
###################################################
## First construct logarithm of scrap rate
pdata$lscrap <- log(pdata$scrap)
## Create lag of grant
pdata$grant.1 <- lag(pdata$grant,1)

## Replace NAs with 0
cut <- seq(from=1,to=length(pdata$grant),by=3)
pdata$grant.1[cut] <- 0


###################################################
### code chunk number 8: plm.pooled
###################################################
## Estimate pooled model
model.pooled.scrap <- plm(lscrap~d88+d89+grant+grant.1,data=pdata,model="pooling")


###################################################
### code chunk number 9: sum.pool
###################################################
sum.pooled.scrap <- summary(model.pooled.scrap)
## Print out results to screen
sum.pooled.scrap


###################################################
### code chunk number 10: plm.pooled.1
###################################################
pdata$lscrap.1 <- lag(pdata$lscrap,1)
## Estimate pooled model
model.pooled.scrap1 <- plm(lscrap~d88+grant+grant.1+lscrap.1,data=pdata,model="pooling")

sum.pooled.scrap1 <- summary(model.pooled.scrap1)
## Print out results to screen
sum.pooled.scrap1


###################################################
### code chunk number 11: Ram.1-3.pool (eval = FALSE)
###################################################
## ## install pwt package
## install.packages("pwt")


###################################################
### code chunk number 12: Ram.1-3.pool
###################################################
##load pwt library
library(pwt)

## First replicate based on PWT6.1
data("pwt6.1")

## Create data.frame
data6.1<- data.frame(pwt6.1)

#Subset of years 1960-2000, to match Ram
data6.1.ram <- data.frame(subset(data6.1,data6.1$year>1959 & data6.1$year<2001))

## First see which countries only have a single observation over the entire period
## Ram has 154 countries, but we have 168 countries
uni.country <- unique(data6.1.ram$country)
length(uni.country)

## Now keep only pop, rgdpch and openk (Ram uses openc -- current prices)
## But rgdpch is in chain prices !!#$#@
check.ram <- na.omit(data6.1.ram[,c(1:4,10,15,20,24)])

## Which countries have a single observation
singleyear.store <- as.numeric()

for (i in 1:length(uni.country)){
  
	c.id <- uni.country[i]
	
	singleyear.store[i] <- length(which(check.ram$country==c.id))

}

num.single <- length(which(singleyear.store==1))

## Remove the single year countries
if(num.single>0){

	ram.omit <- uni.country[which(singleyear.store==1)]

	id.omit <- which(check.ram$country%in%ram.omit)
	check.ram <- check.ram[-id.omit,]

}

## Subset of years 1960-2000, to match Ram
pdata6.1.ram <- pdata.frame(check.ram,index=c("country","year"))

## Estimate Pooled OLS w/ Heteroscedasticity robust standard errors
## Table 1, Column (1)
model1.1 <- plm(log(cg)~log(pop)+log(rgdpch),
				model="pool",
				data=pdata6.1.ram)

robust.t.1.1 <- coefficients(model1.1)/sqrt(diag(vcovHC(model1.1,type="HC0",
  												cluster="time",
													method="white1")))
coefficients(model1.1)
robust.t.1.1

## Table 2, Column (1)
model2.1 <- plm(log(openc)~log(pop)+log(rgdpch),
				model="pool",
				data=pdata6.1.ram)

robust.t.2.1 <- coefficients(model2.1)/sqrt(diag(vcovHC(model2.1,type="HC0",
  												cluster="time",
													method="white1")))
coefficients(model2.1)
robust.t.2.1

## Table 3, Column (1)
model3.1 <- plm(log(cg)~log(openc)+log(rgdpch),
				model="pool",
				data=pdata6.1.ram)

robust.t.3.1 <- coefficients(model3.1)/sqrt(diag(vcovHC(model3.1,type="HC0",
  												cluster="time",
													method="white1")))
coefficients(model3.1)
robust.t.3.1



