### R code from vignette source 'PanelExercise3.Rnw'
### Encoding: UTF-8

###################################################
### code chunk number 1: Munnell_ExampleA
###################################################
library(plm)
data("Produc")

pubcap.data <- Produc

## Replicate models in Baltagi and Pinnoi (1995, Table 1.)
## We will estimate both the pooled models and 
## the within transformation

## Take logs of pcap, hwy, water, util, pc, gsp and emp
pubcap.data$lpubc <- log(pubcap.data$pcap)
pubcap.data$lhwy  <- log(pubcap.data$hwy)
pubcap.data$lwatr <- log(pubcap.data$water)
pubcap.data$lutil <- log(pubcap.data$util)
pubcap.data$lprvc <- log(pubcap.data$pc)
pubcap.data$lgsp  <- log(pubcap.data$gsp)
pubcap.data$lemp  <- log(pubcap.data$emp)

## Pooled OLS, no public capital, 
## Cobb-Douglas specification
model.pool1 <- plm(lgsp~lprvc+lemp+unemp,
                   data=pubcap.data,model="pooling")

## Pooled OLS, aggregate public capital, 
##Cobb-Douglas specification
model.pool2 <- plm(lgsp~lprvc+lemp+lpubc+unemp,
                   data=pubcap.data,model="pooling")

## Pooled OLS, decomposed public capital, 
## Cobb-Douglas specification
model.pool3 <- plm(lgsp~lprvc+lemp+lhwy+lwatr+lutil+unemp,
                   data=pubcap.data,model="pooling")

## Fixed Effects Framework, no public capital, 
## Cobb-Douglas specification
model.wn1 <- plm(lgsp~lprvc+lemp+unemp,
                 data=pubcap.data,
                 model="within",effect="individual")

## Fixed Effects Framework, aggregate public capital, 
## Cobb-Douglas specification
model.wn2 <- plm(lgsp~lprvc+lemp+lpubc+unemp,
                 data=pubcap.data,
                 model="within",effect="individual")

## Fixed Effects Framework, decomposed public capital, 
## Cobb-Douglas specification
model.wn3 <- plm(lgsp~lprvc+lemp+lhwy+lwatr+lutil+unemp,
                 data=pubcap.data,
                 model="within",effect="individual")


###################################################
### code chunk number 2: Munnell_ExampleB
###################################################
sum.pool1 <- summary(model.pool1)
sum.pool2 <- summary(model.pool2)
sum.pool3 <- summary(model.pool3)

sum.wn1 <- summary(model.wn1)
sum.wn2 <- summary(model.wn2)
sum.wn3 <- summary(model.wn3)

## Print out Coefficient estimates and t-statistics
sum.pool1$coefficients[,c(1,3)]
sum.pool2$coefficients[,c(1,3)]
sum.pool3$coefficients[,c(1,3)]

sum.wn1$coefficients[,c(1,3)]
sum.wn2$coefficients[,c(1,3)]
sum.wn3$coefficients[,c(1,3)]

###################################################
### code chunk number 3: VellaVerbeek_ExampleA
###################################################
VV.data <- read.table("VV-DATA.DAT",h=F)

names(VV.data) <- c("NR", "YEAR", "AG", "BLACK", "BUS", "CON", 
                 "ENT", "EXPER", "FIN", "HISP", "HLTH", 
                 "HOURS", "MAN", "MAR", "MIN", "NC", "NE", 
                 "OCC1", "OCC2", "OCC3", "OCC4", "OCC5", 
                 "OCC6", "OCC7", "OCC8", "OCC9", "PER", 
                 "PRO", "PUB", "RUR", "SOUTH", "SCHOOL", 
                 "TRA", "TRAD", "UNION", "WAGE")

## Replicate columns 1-4 in Vella and Verbeek (1998, Table III)

model1 <- lm(WAGE~UNION+SCHOOL+EXPER+I(EXPER^2)+HISP+
               BLACK+RUR+MAR+HLTH+AG+MIN+CON+TRAD+
               TRA+FIN+BUS+PER+ENT+MAN+PRO+SOUTH+NC+
               NE+factor(YEAR),
             data=VV.data)

model2 <- lm(WAGE~UNION+SCHOOL+EXPER+I(EXPER^2)+HISP+
               BLACK+RUR+MAR+HLTH+AG+MIN+CON+TRAD+
               TRA+FIN+BUS+PER+ENT+MAN+PRO+SOUTH+NC+
               NE+factor(YEAR)+OCC1+OCC2+OCC3+OCC4+
               OCC5+OCC6+OCC7+OCC8,
             data=VV.data)

## Construct pdata.frame
pdata <- pdata.frame(VV.data,index=c("NR","YEAR"))

model3 <- plm(WAGE~UNION+EXPER+I(EXPER^2)+
                RUR+MAR+HLTH+AG+MIN+CON+TRAD+
                TRA+FIN+BUS+PER+ENT+MAN+PRO+
                SOUTH+NC+NE,
              data=pdata,
              effect="individual",model="within")

model4 <- plm(WAGE~UNION+EXPER+I(EXPER^2)+
                RUR+MAR+HLTH+AG+MIN+CON+TRAD+
                TRA+FIN+BUS+PER+ENT+MAN+PRO+
                SOUTH+NC+NE+OCC1+OCC2+OCC3+
                OCC4+OCC5+OCC6+OCC7+OCC8,
              data=pdata,
              effect="individual",model="within")


###################################################
### code chunk number 4: VellaVerbeek_ExampleB
###################################################
sum.pool1 <- summary(model1)
sum.pool2 <- summary(model2)

sum.wn1 <- summary(model3)
sum.wn2 <- summary(model4)

## Print out Coefficient estimates and t-statistics
sum.pool1$coefficients[1:10,c(1,3)]
sum.pool2$coefficients[1:10,c(1,3)]

sum.wn1$coefficients[1:6,c(1,3)]
sum.wn2$coefficients[1:6,c(1,3)]


###################################################
### code chunk number 5: VellaVerbeek_ExampleC
###################################################
# Estimate model

pdata$D81 <- ifelse(pdata$YEAR==1981,1,0)
pdata$D82 <- ifelse(pdata$YEAR==1982,1,0)
pdata$D83 <- ifelse(pdata$YEAR==1983,1,0)
pdata$D84 <- ifelse(pdata$YEAR==1984,1,0)
pdata$D85 <- ifelse(pdata$YEAR==1985,1,0)
pdata$D86 <- ifelse(pdata$YEAR==1986,1,0)
pdata$D87 <- ifelse(pdata$YEAR==1987,1,0)

vvmodel <- plm(WAGE~UNION+MAR+I(SCHOOL*D81)+
                 I(SCHOOL*D82)+I(SCHOOL*D83)+
                 I(SCHOOL*D84)+I(SCHOOL*D85)+
                 I(SCHOOL*D86)+I(SCHOOL*D87),
              data=pdata,
              effect="individual",model="within")
						
psumvv <- summary(vvmodel)
psumvv


###################################################
### code chunk number 6: VellaVerbeek_ExampleD
###################################################
library(gregmisc)
## Plot out effects of education over time
## 95% Confidence Bands
n <- psumvv$fstatistic$parameter[2]
ciw <- qt(0.975,n)*psumvv$coefficients[3:9,2]
eff <- psumvv$coefficients[3:9,1]
t <- c(1981,1982,1983,1984,1985,1986,1987)

plotCI(x=eff, uiw=ciw, col="black", 
				barcol="blue",xlim=c(1,7),xaxt="n",
				xlab="Year",ylab="Return to Education",
				main="Changes in Return to Education (base 1980)")
axis(side=1, at=1:7, labels=t, cex=0.7)
abline(h=0,col="black",lty=2,lwd=2)

## Estimated return to education has been increasing over time 
## and is statistically significantly different from 1980 in 
## 1986 and 1987.

###################################################
### code chunk number 7: VellaVerbeek_ExampleE
###################################################
vvmodel.A <- plm(WAGE~UNION+MAR+EXPER+I(EXPER^2)+
                   I(SCHOOL*D81)+I(SCHOOL*D82)+
                   I(SCHOOL*D83)+I(SCHOOL*D84)+
                   I(SCHOOL*D85)+I(SCHOOL*D86)+
                   I(SCHOOL*D87),
              data=pdata,
              effect="individual",model="within")
  					
psumvv.A <- summary(vvmodel.A)
## Plot out effects of education over time
## 95% Confidence Bands
n <- psumvv.A$fstatistic$parameter[2]
ciw <- qt(0.975, n)*psumvv.A$coefficients[5:11,2]
eff <- psumvv.A$coefficients[5:11,1]
t <- c(1981,1982,1983,1984,1985,1986,1987)

plotCI(x=eff, uiw=ciw, col="black", 
  			barcol="blue",xlim=c(1,7),xaxt="n",
				xlab="Year",ylab="Return to Education",
				main="Changes in Return to Education (base 1980)")
axis(side=1, at=1:7, labels=t, cex=0.7)
abline(h=0,col="black",lty=2,lwd=2)

###################################################
### code chunk number 8: VellaVerbeek_ExampleF
###################################################
library(car)

## Test for joint significance of education*time effects, 
hypothesis.matrix <- c(0,0,1,0,0,0,0,0,0,
                       0,0,0,1,0,0,0,0,0,
                       0,0,0,0,1,0,0,0,0,
                       0,0,0,0,0,1,0,0,0,
                       0,0,0,0,0,0,1,0,0,
                       0,0,0,0,0,0,0,1,0,
                       0,0,0,0,0,0,0,0,1) 

hypothesis.matrix <- matrix(hypothesis.matrix,7,9,byrow=TRUE)

## The 6 corresponds to the number of restrictions (# of 
## monthly dummies), and the 9 to the 
## number of parameters in the unrestricted model.

## Here we have a matrix since we have a multiple hypothesis.
rhs <- c(0,0,0,0,0,0,0)

## This is a vector since we have a multiple hypothesis. The 0s 
## correspond to the values assumed in the null hypothesis.

test <- linearHypothesis(vvmodel,
						hypothesis.matrix=hypothesis.matrix,
						rhs=rhs)
test


