### R code from vignette source 'PanelExercise5.Rnw'
### Encoding: UTF-8

###################################################
### code chunk number 1: Load
###################################################
library(plm)

## Load in dataset of Baltagi and Griffin (1983)
data("Gasoline")


###################################################
### code chunk number 2: Estimate_USA
###################################################
gas.USA <- lm(lgaspcar~lincomep+lrpmg+
                    lcarpcap,
              data=Gasoline,subset=(country=="Austria"))

###################################################
### code chunk number 3: Estimate_USA
###################################################
country.coef <- matrix(0,18,4)

country.id <- unique(Gasoline$country)

for (j in 1:length(country.id)){

country.coef[j,] <- coefficients(lm(lgaspcar~lincomep+
                                      lrpmg+
                                      lcarpcap,
                                    data=Gasoline,
                                    subset=(country==country.id[j])))
}

summary(country.coef)

## A quicker way to do this is to use the pvcm()
## command in plm
gas.vc <-  pvcm(lgaspcar~lincomep+
                  lrpmg+lcarpcap, 
                data = Gasoline)

summary(coefficients(gas.vc))


###################################################
### code chunk number 4: Test_Pool
###################################################
gas.pool <- plm(lgaspcar~lincomep+lrpmg+
                    lcarpcap,
                model="pooling",
                data=Gasoline)

gas.wn <- plm(lgaspcar~lincomep+lrpmg+
                    lcarpcap,
                model="within",
                effect="individual",
                data=Gasoline)

## Now test for poolability and for presence of 
## unobserved additive heterogeneity

## Test for unobserved heterogeneity
## NOTE, the first model must be the
## within model!
unobs.test <- pFtest(gas.wn,gas.pool)

unobs.test

## Test for pooling
## 
pool.test <- pooltest(gas.wn,gas.vc)

pool.test


###################################################
### code chunk number 5: Test_Hausman
###################################################
## Estimate Random Effects Model
gas.rd.nerl <- plm(lgaspcar~lincomep+lrpmg+
                       lcarpcap,
                     model="random",
                     effect="individual",
                     random.method="nerl",
                     data=Gasoline)

gas.rd.swar <- plm(lgaspcar~lincomep+lrpmg+
                       lcarpcap,
                     model="random",
                     effect="individual",
                     random.method="swar",
                     data=Gasoline)

gas.rd.wh <- plm(lgaspcar~lincomep+lrpmg+
                       lcarpcap,
                     model="random",
                     effect="individual",
                     random.method="walhus",
                     data=Gasoline)

gas.rd.amem <- plm(lgaspcar~lincomep+lrpmg+
                       lcarpcap,
                     model="random",
                     effect="individual",
                     random.method="amemiya",
                     data=Gasoline)

## Now perform the Hausman test. 
phtest.amem <- phtest(gas.wn,gas.rd.amem)
phtest.nerl <- phtest(gas.wn,gas.rd.nerl)
phtest.swar <- phtest(gas.wn,gas.rd.swar)
phtest.wh   <- phtest(gas.wn,gas.rd.wh)

## Print out p values
phtest.amem$p.value
phtest.nerl$p.value
phtest.swar$p.value
phtest.wh$p.value


###################################################
### code chunk number 6: Models_HealthAid
###################################################
## Load the data. Need the foreign package since this is
## a STATA dataset.
library(foreign)
health.data <- read.dta(file="Thierry.dta")

## First lets condense names of variables to make things easier
names(health.data) <- c("country","code","year","demo","gdp.gro",
                        "life.ex","docs","urbanpop","health")

## Now convert to a panel data.frame
phealth.data <- pdata.frame(health.data,index=c("country","year"))

## Now lets estimate a pooled model, the within model, and a random 
## effects model. Then we will test for unobserved effects and 
## appropriate framework

## Pooled model
health.pool <- plm(life.ex~log(health)+demo+gdp.gro+
                     urbanpop,
                   data=phealth.data,
                   model="pooling")

## Within model
health.wn <- plm(life.ex~log(health)+demo+gdp.gro+
                     urbanpop,
                   data=phealth.data,
                   model="within",effect="individual")

## Random Effects model
health.rd <- plm(life.ex~log(health)+demo+gdp.gro+
                     urbanpop,
                   data=phealth.data,
                   model="random",
                 effect="individual",
                 random.method="swar")

## Now test for unobserved effects
pFtest(health.pool,health.wn)

plmtest(health.wn,effect="individual")

## Now Hausman test
phtest(health.wn,health.rd)


health.pool <- lm(life.ex~log(health)+demo+gdp.gro+
                     urbanpop,
                   data=health.data)