### R code from vignette source 'PanelExercise8.Rnw'
### Encoding: UTF-8

###################################################
### code chunk number 1: Load
###################################################
library(plm)

data("Crime")

Crime.data <- Crime

## Add in logs of main variables
Crime.data$lcrmrte  <- log(Crime.data$crmrte)
Crime.data$lprbarr  <- log(Crime.data$prbarr)
Crime.data$lprbconv <- log(Crime.data$prbconv)
Crime.data$lprbpris <- log(Crime.data$prbpris)
Crime.data$lavgsen  <- log(Crime.data$avgsen)
Crime.data$lpolpc   <- log(Crime.data$polpc)
Crime.data$ldensity <- log(Crime.data$density)
Crime.data$lwcon    <- log(Crime.data$wcon)
Crime.data$lwtuc    <- log(Crime.data$wtuc)
Crime.data$lwtrd    <- log(Crime.data$wtrd)
Crime.data$lwfir    <- log(Crime.data$wfir)
Crime.data$lwser    <- log(Crime.data$wser)
Crime.data$lwmfg    <- log(Crime.data$wmfg)
Crime.data$lwfed    <- log(Crime.data$wfed)
Crime.data$lwsta    <- log(Crime.data$wsta)
Crime.data$lwloc    <- log(Crime.data$wloc)
Crime.data$lpctymle <- log(Crime.data$pctymle)
Crime.data$lpctmin  <- log(Crime.data$pctmin)
Crime.data$ltaxpc   <- log(Crime.data$taxpc)
Crime.data$lmix     <- log(Crime.data$mix)
Crime.data$urban    <- ifelse(Crime.data$smsa=="yes",1,0)
Crime.data$west     <- ifelse(Crime.data$region=="west",1,0)
Crime.data$central  <- ifelse(Crime.data$region=="central",1,0)

## Pooled Model
pool.crime <- plm(lcrmrte~lprbarr+lprbconv+lprbpris+
  			lavgsen+lpolpc+
				ldensity+lwcon+lwtuc+lwtrd+lwfir+
				lwser+lwmfg+lwfed+lwsta+lwloc+
				lpctymle+lpctmin+west+central+
				urban,
				model="pooling",
				data=Crime.data)

## Generic fixed effects estimation 

fe.crime <- plm(lcrmrte~lprbarr+lprbconv+lprbpris+
  			lavgsen+lpolpc
				ldensity+lwcon+lwtuc+lwtrd+lwfir+
				lwser+lwmfg+lwfed+lwsta+lwloc+
				lpctymle+lpctmin+west+central+
				urban+factor(year),
				model="within",
				effect="individual",
				data=Crime.data)

b.crime <- plm(lcrmrte~lprbarr+lprbconv+lprbpris+
				lavgsen+lpolpc+
				ldensity+lwcon+lwtuc+lwtrd+lwfir+
				lwser+lwmfg+lwfed+lwsta+lwloc+
				lpctymle+lpctmin+west+central+
				urban,
				model="between",
				effect="individual",
				data=Crime.data)

## Random Effects, using SWAR
rd.crime <- plm(lcrmrte~lprbarr+lprbconv+lprbpris+
  			lavgsen+lpolpc+
				ldensity+lwcon+lwtuc+lwtrd+lwfir+
				lwser+lwmfg+lwfed+lwsta+lwloc+
				lpctymle+lpctmin+west+central+
				urban,
				model="random",
				effect="individual",
        random.method="swar",
				data=Crime.data)


###################################################
### code chunk number 2: Table
###################################################
library(stargazer)

stargazer(pool.crime,fe.crime,b.crime,rd.crime,
          no.space=TRUE,label="table1",
          keep=c("lprbarr","lprbconv","lprbpris",
                 "lavgsen","lpolpc"),
          column.labels=c("Pool","FE","BW","Random"),
          column.separate=c(1,1,1,1),
          model.numbers=FALSE,
          column.sep.width="2pt",
          omit.stat=c("f"))


###################################################
### code chunk number 3: 2SLS
###################################################
## 2SLS fixed effects estimation 

fe2SLS.crime <- plm(lcrmrte~lprbarr+lprbconv+lprbpris+
					lavgsen+lpolpc+
					ldensity+lwcon+lwtuc+lwtrd+lwfir+
					lwser+lwmfg+lwfed+lwsta+lwloc+
					lpctymle+lpctmin+west+central+
					urban+factor(year)|ltaxpc+lmix+
					lprbconv+lprbpris+lavgsen+
					ldensity+lwcon+lwtuc+lwtrd+lwfir+
					lwser+lwmfg+lwfed+lwsta+lwloc+
					lpctymle+lpctmin+west+central+
					urban+factor(year),
					model="within",
					effect="individual",
					data=Crime.data)

## 2SLS between estimation 

b2SLS.crime <- plm(lcrmrte~lprbarr+lprbconv+lprbpris+
					lavgsen+lpolpc+
					ldensity+lwcon+lwtuc+lwtrd+lwfir+
					lwser+lwmfg+lwfed+lwsta+lwloc+
					lpctymle+lpctmin+west+central+
					urban|ltaxpc+lmix+
					lprbconv+lprbpris+lavgsen+
					ldensity+lwcon+lwtuc+lwtrd+lwfir+
					lwser+lwmfg+lwfed+lwsta+lwloc+
					lpctymle+lpctmin+west+central+
					urban,
					model="between",
					effect="individual",
					data=Crime.data)

## EC2SLS fixed effects estimation 

EC2SLS.crime <- plm(lcrmrte~lprbarr+lprbconv+lprbpris+
					lavgsen+lpolpc+
					ldensity+lwcon+lwtuc+lwtrd+lwfir+
					lwser+lwmfg+lwfed+lwsta+lwloc+
					lpctymle+lpctmin+west+central+
					urban+factor(year)|ltaxpc+lmix+
					lprbconv+lprbpris+lavgsen+
					ldensity+lwcon+lwtuc+lwtrd+lwfir+
					lwser+lwmfg+lwfed+lwsta+lwloc+
					lpctymle+lpctmin+west+central+
					urban+factor(year),
					model="random",
					effect="individual",
					inst.method="baltagi",
					data=Crime.data)


###################################################
### code chunk number 4: Table2SLS
###################################################
stargazer(fe.crime,fe2SLS.crime,b2SLS.crime,EC2SLS.crime,
          no.space=TRUE,label="table2",
          keep=c("lprbarr","lprbconv","lprbpris",
                 "lavgsen","lpolpc"),
          column.labels=c("FE","FE2SLS","BW2SLS","EC2SLS"),
          column.separate=c(1,1,1,1),
          model.numbers=FALSE,
          column.sep.width="2pt",
          omit.stat=c("f"))


###################################################
### code chunk number 5: HT
###################################################
## Hausman-Taylor Estimation of a wage equation
Wages <- read.csv(file="Wages.csv",h=T)

Wages$exp2 <- (Wages$exp)^2

pdata.Wages <- pdata.frame(Wages,index=c("ID","YEAR"))

fe.wage <- plm(lwage~wks+south+smsa+married+
                 exp+exp2+bluecol+ind+
                 union+sex+black+ed,
					  model="within",
					  effect="individual",
					  data=pdata.Wages)

rd.wage <- plm(lwage~wks+south+smsa+married+
                 exp+exp2+bluecol+ind+
                 union+sex+black+ed,
  				  model="random",
            random.method="swar",
					  effect="individual",
					  data=pdata.Wages)

ht.wage <- plm(lwage~wks+south+smsa+married+
                 exp+exp2+bluecol+ind+
                 union+sex+black+ed|bluecol+
                 south+smsa+ind+sex+black,
    			  model="ht",
					  effect="individual",
					  data=pdata.Wages)


###################################################
### code chunk number 6: TableHT
###################################################
## Create empty summary.plm object since
## stargazer does not support summary.pht

pht.wage <- rd.wage
pht.wage$coefficients <- ht.wage$coefficients
pht.wage$vcov <- ht.wage$vcov

stargazer(fe.wage,rd.wage,pht.wage,
          no.space=TRUE,label="table3",
          column.labels=c("FE","RE","HT"),
          column.separate=c(1,1,1),
          model.numbers=FALSE,
          column.sep.width="2pt",
          omit.stat=c("f"))


